# -*- coding: utf-8 -*-
"""
pyrobex.errors

pyrobex-specific errors

Author: Jacob Reinhold (jcreinhold@gmail.com)
Created on: May 5, 2021
"""

__all__ = ["PyRobexError"]


class PyRobexError(Exception):
    pass
